---
title: Connection
---

### Connection

The GitHub extension comes with a pre-configured `connection` class to use for making API calls to GitHub's v1.1 API.


#### Configuring

Before you can leverage this extension you need to head to `Settings > Extensions > GitHub Extension` and enter your API credentials from [https://developer.github.com/en/apps](https://developer.github.com/en/apps).


#### Getting Started

To get started you will need to resolve or inject the connection class into your code. The connection class will already be configured to your authentication settings. Below is an example of a basic Laravel command:

    <?php namespace Anomaly\ExampleTheme\Command;
    
    use Abraham\GitHubOAuth\GitHubOAuth;
    use Anomaly\GitHubExtension\GitHub\GitHubConnection;
    
    class GetRecentTweets
    {
    
        public function handle(GitHubConnection $connection)
        {
        
            /* @var GitHubOAuth $connection */
            $recent = $connection->get(
                'statuses/user_timeline',
                [
                    'screen_name' => 'pyrocms',
                    'include_rts' => false,
                    'count'       => 10,
                ]
            );
    
            return $recent;
        }
    }

Notice how the `$connection` is hinted as the `GitHubOAuth` class. This is because it's a wrapper for it. If you need to get the literal `GitHubOAuth` instance for any reason you can use `getConnection`:
  
    $real = $connection->getConnection();


#### GitHubOAuth Documentation

For more information on available functionality please refer to the documentation for the package: [https://githuboauth.com/](https://githuboauth.com/)
